@@ -1,6 +1,6 @@
 #
-#  Copyright (C) 2006 Friedrich Leisch
-#  $Id: barplot.R 4259 2009-02-01 16:08:08Z leisch $
+#  Copyright (C) 2006-2009 Friedrich Leisch
+#  $Id: barplot.R 4281 2009-02-20 06:02:41Z leisch $
 #
 
 setMethod("barplot", "kccasimple",
@@ -94,43 +94,60 @@ function (height, bycluster = TRUE, oneplot = TRUE,
 
 setMethod("barchart", "kccasimple",
 function(x, data, xlab="", strip.prefix="Cluster ",
-         col=NULL, mcol="darkred", panel=NULL, which=NULL, ...)
+         col=NULL, mcol="darkred", which=NULL, ...)
 {
+    SIZE <- info(x, "size")
+    LABELS <-
+        paste(strip.prefix, 1:x@k, ": ", SIZE, " (",
+              round(100 * SIZE/sum(SIZE), 2), "%)", sep="")
+
+    Barchart(x=x@centers, m=x@xcent, labels=LABELS, xlab=xlab,
+             col=col, mcol=mcol, which=which, ...)
+})
+
+
+### Currently not exported, hence document arguments here:
+### x: matrix of cluster centers
+### m: vector with location of total population
+### labels: text for panel header strips (default is rownames(x))
+### REST: see barchart method for kccasimple objects
+Barchart <- function(x, m, labels=NULL, xlab="", col=NULL, mcol="darkred", 
+                     which=NULL, ...)
+{
+    x <- as.matrix(x)
+    m <- as.vector(m)
+
+    if(!is.null(labels))
+        rownames(x) <- rep(labels, length=nrow(x))
+    
     if(is.null(col))
         col <- flxColors(color="light")
 
+    col <- rep(col, length=nrow(x))
+
     if(is.null(which))
-        which <- seq(1, ncol(x@centers))
+        which <- seq(1, ncol(x))
 
-    col <- rep(col, x@k)
-
-    TAB <- x@centers[,which]
+    x <- x[,which]
     ## sonst musz man die barplots von unten nach oben lesen
-    TAB <- TAB[,ncol(TAB):1]
-    xcent <- rev(x@xcent[which])
+    x <- x[,ncol(x):1]
+    m <- rev(m[which])
 
+    x <- as.data.frame(as.table(x))
 
-    SIZE <- info(x, "size")
-    rownames(TAB) <-
-        paste(strip.prefix, 1:nrow(TAB), ": ", SIZE, " (",
-              round(100 * SIZE/sum(SIZE), 2), "%)", sep="")
-    TAB <- as.data.frame(as.table(TAB))
+    panel <- createBarchartPanel(m=m, col=col, mcol=mcol)
 
-    panel <- createBarchartPanel(m=xcent, col=col,
-                                 mcol=mcol, which=which)
-d
-    barchart(Var2~Freq|Var1, data=TAB,
+    barchart(Var2~Freq|Var1, data=x,
              panel=panel, as.table=TRUE,
              xlab=xlab, ...)
-})
+}
+
 
 createBarchartPanel <- function(m, col, mcol)
 {
     KKK <- 1
     KKKplus <- function() KKK <<- KKK+1
 
-    ## sonst musz man die barplots von unten nach oben lesen
-
     mypanel <- function(x, y, shade=FALSE, diff=NULL, ...)
     {
         if(is.null(diff))
@@ -140,7 +157,7 @@ createBarchartPanel <- function(m, col, mcol)
 
         grey <- flxColors(color="dark", grey=TRUE)
         COL <- col[KKK]
-        MCOL <- mcol
+        MCOL <- rep(mcol, length=length(x))
         BCOL <- "black"
             
         if(shade){
@@ -154,8 +171,8 @@ createBarchartPanel <- function(m, col, mcol)
             MCOL[d1|d2] <- mcol
             BCOL[d1|d2] <- "black"
         }
-        
-            
+
+        MCOL[is.na(x)] <- NA
         grid.segments(x0=0, y0=1:length(x), x1=m, y1=1:length(x),
                       gp=gpar(col=MCOL),
                       default.units="native")
